@@ -5,22 +5,22 @@ eel.test2 <- function(y1, y2, tol = 1e-07, R = 0, graph = FALSE) {
   ## If R = 1, the James corrected chi-square distribution is used
   ## If R = 2, the MNV F distribution is used
   ## If R > 2, bootstrap calibration is implemented
-  eel2 <- function(x, y) {
+  dm <- dim(y1)
+  n1 <- dm[1]    ;    d <- dm[2]
+  n2 <- dim(y2)[2]
 
-    d <- dim(x)[2]
+  eel2 <- function(x, y, n1, n2, d) {
     ## next is the root finding function
     ### step 1
     lam1 <- numeric(d)
-
-    fx1 <- exp( as.vector( x %*% lam1 ) )
-    fx2 <- sum(fx1)
-    fx2a <- x * fx1
+    fx1 <- numeric(n1)
+    fx2 <- n1
+    fx2a <- x
     fx3 <- Rfast::colsums( fx2a )
     fx4 <- fx3 / fx2
-
-    fy1 <- exp( as.vector( - y %*% lam1 ) )
-    fy2 <- sum(fy1)
-    fy2a <- y * fy1
+    fy1 <- numeric(n2)
+    fy2 <- n2
+    fy2a <- y
     fy3 <- Rfast::colsums( fy2a )
     fy4 <- fy3 / fy2
     f <- fx4 - fy4
@@ -37,7 +37,6 @@ eel.test2 <- function(y1, y2, tol = 1e-07, R = 0, graph = FALSE) {
       fx2a <- x * fx1
       fx3 <- colSums( fx2a )
       fx4 <- fx3 / fx2
-
       fy1 <- exp( as.vector( - y %*% lam1 ) )
       fy2 <- sum(fy1)
       fy2a <- y * fy1
@@ -54,14 +53,13 @@ eel.test2 <- function(y1, y2, tol = 1e-07, R = 0, graph = FALSE) {
     n1 <- dim(x)[1]   ;   n2 <- dim(y)[1]
     stat <-  - 2 * sum( log( n1 * p1) ) - 2 * sum( log(n2 * p2) )
     pvalue <- pchisq(stat, d, lower.tail = FALSE)
-
     info <- c(stat, pvalue, d)
     names(info) <- c("statistic", "p-value", "degrees of freedom")
     list(p1 = p1, p2 = p2, lambda = lam2, iters = i, info = info)
   }
 
   runtime <- proc.time()
-  res <- try( eel2(y1, y2), silent = TRUE )
+  res <- try( eel2(y1, y2, n1, n2, d), silent = TRUE )
   runtime <- proc.time() - runtime
   res$runtime <- runtime
   res$note <- paste("Chi-square approximation")
@@ -77,7 +75,6 @@ eel.test2 <- function(y1, y2, tol = 1e-07, R = 0, graph = FALSE) {
     res <- res
 
   } else if ( R == 1 ) {
-
     test <- as.numeric( res$info[1] )
     d <- dim(y1)[2]
     delta <- james(y1, y2, R = 1)$info[3]
@@ -87,9 +84,7 @@ eel.test2 <- function(y1, y2, tol = 1e-07, R = 0, graph = FALSE) {
     res$info[2] <- pvalue
     res$note <- paste("James corrected chi-square approximation")
 
-
   } else if ( R == 2 ) {
-
     test <- as.numeric( res$info[1] )
     d <- dim(y1)[2]
     dof <- james(y1, y2, R = 2)$info[5]
@@ -120,12 +115,11 @@ eel.test2 <- function(y1, y2, tol = 1e-07, R = 0, graph = FALSE) {
       mu <- solve( a1 + a2, a1 %*% m1 + a2 %*% m2 )
       zx <- y1 + rep( - m1 + mu, rep(n1, d) )
       zy <- y2 + rep( - m2 + mu, rep(n2, d) )
-
       tb <- numeric(R)
       for ( i in 1:R ) {
         b1 <- sample(1:n1, n1, replace = TRUE)
         b2 <- sample(1:n2, n2, replace = TRUE)
-        tb[i] <- try( eel2(zx[b1, ], zy[b2, ]), silent = TRUE )$info[1]
+        tb[i] <- try( eel2(zx[b1, ], zy[b2, ], d), silent = TRUE )$info[1]
       }
       pvalue <- ( sum(tb > test ) + 1 ) / (R + 1)
 
@@ -133,7 +127,6 @@ eel.test2 <- function(y1, y2, tol = 1e-07, R = 0, graph = FALSE) {
         hist(tb, xlab = "Bootstrapped test statistic", main = " ")
         abline(v = test, lty = 2, lwd = 2)  ## The line is the test statistic
       }
-
     } else pvalue <- 1 / (R + 1)
 
     res$info[2] <- pvalue
@@ -141,11 +134,9 @@ eel.test2 <- function(y1, y2, tol = 1e-07, R = 0, graph = FALSE) {
     runtime <- runtime + durat
     res$runtime <- runtime
     res$note <- paste("Bootstrap calibration")
-
   }
 
   res
-
 }
 
 
